@@ -50,7 +50,7 @@ class SQLiteDatabase:
             self._cursor_pool = cursor_pool.CursorPool(self.connection)
             await self.__init_tables_list()
         except (sqlite3.OperationalError, sqlite3.DatabaseError) as err:
-            raise errors.DatabaseNotFoundError(err)
+            raise errors.DatabaseNotFoundError(f"{err} (file: {self.file_name})")
 
     async def create_index(self, table, columns):
         await self.__execute_index_creation(
@@ -208,6 +208,12 @@ class SQLiteDatabase:
             size=size,
         )
 
+    async def delete(self, table, **kwargs):
+        return await self.__execute_delete(
+            table,
+            self.__where_clauses_from_kwargs(**kwargs),
+        )
+
     def __where_clauses_from_kwargs(self, should_quote_value=True, **kwargs) -> str:
         return self.__where_clauses_from_operations(
             list(kwargs.keys()),
@@ -289,6 +295,11 @@ class SQLiteDatabase:
             self.logger.error(f"An error occurred when executing select : {err}")
         return []
 
+    async def __execute_delete(self, table, where_clauses):
+        async with self.aio_cursor() as cursor:
+            await cursor.execute(f"DELETE FROM {table.value} WHERE {where_clauses} ")
+            # nothing to return, will raise on error
+
     async def check_table_exists(self, table) -> bool:
         async with self.aio_cursor() as cursor:
             await cursor.execute(
@@ -334,7 +345,8 @@ class SQLiteDatabase:
 
     async def stop(self):
         try:
-            await self._cursor_pool.close()
+            if self._cursor_pool is not None:
+                await self._cursor_pool.close()
         finally:
             if self.connection is not None:
                 conn = self.connection
