@@ -19,6 +19,7 @@ from octobot_commons.logging.logging_util import (
     BotLogger,
     set_global_logger_level,
     get_global_logger_level,
+    temporary_log_level,
     get_logger_level_per_handler,
     get_logger,
     set_logging_level,
@@ -35,12 +36,14 @@ from octobot_commons.logging.logging_util import (
     get_errors_count,
     reset_errors_count,
     register_error_notifier,
+    set_enable_web_interface_logs,
 )
 
 __all__ = [
     "BotLogger",
     "set_global_logger_level",
     "get_global_logger_level",
+    "temporary_log_level",
     "get_logger_level_per_handler",
     "get_logger",
     "set_logging_level",
@@ -57,4 +60,5 @@ __all__ = [
     "get_errors_count",
     "reset_errors_count",
     "register_error_notifier",
+    "set_enable_web_interface_logs",
 ]
