@@ -26,6 +26,7 @@ from octobot_commons.profiles.profile_sharing import (
     export_profile,
     install_profile,
     import_profile,
+    import_profile_data_as_profile,
     download_profile,
     download_and_install_profile,
 )
@@ -35,6 +36,7 @@ from octobot_commons.profiles import profile_data
 from octobot_commons.profiles.profile_data import (
     ProfileData,
     ExchangeData,
+    MinimalFund,
     OptionsData,
 )
 
@@ -44,9 +46,11 @@ __all__ = [
     "export_profile",
     "install_profile",
     "import_profile",
+    "import_profile_data_as_profile",
     "download_profile",
     "download_and_install_profile",
     "ProfileData",
     "ExchangeData",
+    "MinimalFund",
     "OptionsData",
 ]
