@@ -24,12 +24,15 @@ import time
 import requests
 import jsonschema
 import octobot_commons.constants as constants
+import octobot_commons.enums as enums
 import octobot_commons.logging as bot_logging
 import octobot_commons.errors as errors
 import octobot_commons.json_util as json_util
 
 # avoid cyclic import
 from octobot_commons.profiles.profile import Profile
+import octobot_commons.profiles.profile_data as profile_data_import
+import octobot_commons.profiles.profile_data_import as profile_data_importer
 
 
 NON_OVERWRITTEN_PROFILE_FOLDERS = []
@@ -152,6 +155,49 @@ def import_profile(
     return profile
 
 
+async def import_profile_data_as_profile(
+    profile_data: profile_data_import.ProfileData,
+    profile_schema: str,
+    aiohttp_session,
+    name: str = None,
+    description: str = None,
+    risk: enums.ProfileRisk = None,
+    bot_install_path: str = ".",
+    origin_url: str = None,
+    logo_url: str = None,
+) -> Profile:
+    """
+    Imports the given ProfileData into the user's profile directory with the "imported_" prefix
+    :param profile_data: path to the profile zipped archive
+    :param profile_schema: the schema to validate profile against
+    :param name: name of the profile folder
+    :param bot_install_path: path to the octobot installation
+    :param origin_url: url the profile is coming from
+    :param logo_url: url the profile avatar
+    :return: The created profile
+    """
+    logger = bot_logging.get_logger("ProfileSharing")
+    import_path = f"{name}-{uuid.uuid4().hex}"
+    try:
+        profile_data.profile_details.name = name
+        await profile_data_importer.convert_profile_data_to_profile_directory(
+            profile_data, description, risk, logo_url, import_path, aiohttp_session
+        )
+        return import_profile(
+            import_path=import_path,
+            profile_schema=profile_schema,
+            name=name,
+            bot_install_path=bot_install_path,
+            origin_url=origin_url,
+        )
+    finally:
+        try:
+            if os.path.isdir(import_path):
+                shutil.rmtree(import_path)
+        except Exception as err:
+            logger.exception(err, True, f"Error when removing profile temp dir: {err}")
+
+
 def download_profile(url, target_file, timeout=60):
     """
     Downloads a profile from the given url
