@@ -13,17 +13,21 @@
 #
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
-
+import sys
 import concurrent.futures as futures
 
 
 # pylint: disable=W0212
 def stop_thread_pool_executor_non_gracefully(executor: futures.ThreadPoolExecutor):
     """
+    Should only be used in python 3.8
     From https://gist.github.com/clchiou/f2608cbe54403edb0b13
     Non graceful and non clean but only way to shutdown a ThreadPoolExecutor
     :param executor: the ThreadPoolExecutor to stop
     """
-    executor.shutdown(False)
-    executor._threads.clear()
-    futures.thread._threads_queues.clear()
+    if sys.version_info.minor >= 9:
+        executor.shutdown(True)
+    else:
+        executor.shutdown(False)
+        executor._threads.clear()
+        futures.thread._threads_queues.clear()
